==> openmsghard-0.0.1.tar.gz: openmsghard-0.0.1/common.h <==
#include <dirent.h>
#include <sys/stat.h>
#include <pthread.h>
#include <mysql.h>
#include <iconv.h>

int pub_ns_sock;
pthread_mutex_t mutx;
int pthread_state;
iconv_t msn_ic[2];







typedef struct _msn_session {
        int trid;


} msn_session;

typedef struct _data {
        int count; /* 1 ŭ */
	int list_num; /* 1 10 ȣο  , ׿ܴ 0 */
        int isdir; 
        char filename[256];
        char initial[44];
        float size;
        char unit[2];
        long ori_date;
        char date[9];
	long ori_size;
}list_data;

typedef struct _file {
        list_data data;
        struct _file *Next;

}list_file;

typedef struct _print_buf {

	const char *header;
	const char *s_tailer;
	const char *f_tailer;
	const char *m_tailer;
	const char *l_tailer;
	const char *help_header;
	const char *help_tailer;
	char *u_header;
	char *u_s_tailer;
	char *u_f_tailer;
	char *u_m_tailer;
	char *u_l_tailer;
	char *u_help_header;
	char *u_help_tailer;
} print_buf;

print_buf *pub_print;
//set_printbuf(&print);

typedef struct _host_info {
	int *sendsock;
	int *recvsock;	
	char ip[16];
	int port;
	long cookie;
	long authcookie;
	char filename[256];
	long filesize;
	char path[2048];
	char type[5];
	int tree_ptr;
	list_file *head;
}host_info;

struct _file_queue {
	int *sendsock;
	int *recvsock;
        char ip[16];
        int port;
        long cookie;
        long authcookie;
        char filename[256];
        long filesize;
        char path[2048];
        char type[5];
	int tree_ptr;
	list_file *head;
	
} file_queue[11];

typedef struct _config {
	char msn_id[256];
	char msn_pw[256];
	char ip[30];
	int port;
	char mysql_id[256];
	char mysql_pw[256];
	char mysql_db[256];
	char intro_message[1024];
	char nick_name[256];
	char msghard_home[2048];
	char user[256];
	char group[256];
	long default_size;
} config;

/* public  */
int queue_ptr;
int dn_ptr;
int dn_flag;
list_file *pub_head;
int pub_max_count;
int pub_file_ptr;
int pub_tree_ptr;
int pub_data_sock;
char pub_present_path[2048];
char user_id[256];

msn_session *pub_session;
config conf;

MYSQL conn;



/* list_file.c */
list_file* get_list_file(char *dirname,int *max_count);
void dostat(char *dirname, char *filename ,list_file *head,list_file *tail);
void show_file_info( char *, struct stat *,list_file *head,list_file *tail,char *filename);
void delete_all(list_file *head,int max_count);
void cd_p(char *old_path,char *new_path);
void cd_mv(char *old_path,char *new_path,char dir);
void mv_present(char *present_path);


/* main.c */
void conv_server(msn_session *session,int *cm_sendsock,int *cm_recvsock,char *user_id,print_buf *print);
void z_handler(int sig);
void set_send_message(msn_session *session,list_file *head,list_file *p,char *u_send_buf,char *u_send_buf1,char *u_send_ptr1,int max_count,int file_ptr ,char *present_path,print_buf *print,char *tmp_format); 
void msn_remove_user(msn_session *session,int *sock,char *username);
void msn_user_add(msn_session *session,int *sock,char *username);
void create_home(char *username);
void *ping_pthread(void *sock);
void *typinguser_pthread(void *sock);
void daemonize();
void change_nickname(msn_session *session,int *sock);

/* connect.c */
int msn_init_session(msn_session *session);
char* getaddr(char *domain);
char* msn_ds_connect(msn_session *session,char *ip_port[]);
int tcp_connect(char *server,int port);
int tcp_bind(char *server,int port,int *serv_sock);
int tcp_recv_accept(int *serv_sock);
int tcp_send_accept(int *serv_sock);

void msn_strtok(char *buf,char *tok[]);
void msn_strtok_null(char *buf,char *tok[]);
void ip_port_tok(char *buf,char *ip_port[]);
void remove_r_n(char *buf);
void msn_strtok_path(char *buf,char *tok[]);
void msn_strtok_n(char *buf,char *tok[]);
void msn_strtok_ft(char *buf,char *new_buf);
void msn_strtok_msg(char *buf,char *tok[]);
void msn_strtok_rm(char *buf,char *tok[]);

/* misc.c */
int check_for_updates(void);
int url_encode(char *str, char *ret, int ret_len);
int url_decode(char *);
int err_exit(char *);
void print_fail(void);
void print_ok(void);
void status(char *);
char *split(char *, char, int);
void usage(void);
void error_handling(char *str);
char* utf8_to_euckr( const char* str );
char* euckr_to_utf8( const char* str );
void utf8encode(iconv_t ic, char *src, char *dest, int obl);
void set_printbuf(print_buf *print);
void set_help_page(msn_session *session,char *u_send_buf1,char *u_send_buf2,print_buf *print);



/* ssl.c */
int https_auth(char *,int,char *,char *,char *,char *,char *,int);

/* filetrans.c */
void file_trans(list_file *head,char *msg_tok[],char *type,int *cm_recvsock,int *cm_sendsock,msn_session *session,pthread_t *file,char *tmp_present_path,int sendnum,int tree_ptr);
void *file_trans_pthread(void *info);
void add_queue(host_info *info);
void del_queue(long cookie);
void file_rename(char *old_name, char *new_name,char *recv_name,char **rename_tok);
void order_queue(int num,long cookie);

/* recvfile.c */
void start_recv(int *data_sock);
void recv_success(int *data_sock);
void recv_failed(int *data_sock);
void ready_recv();


/* sendfile.c */
void start_send(int *data_sock);
void ready_send();


/* msg_proc */
void message_process(list_file *head,char *recv_msg,int *max_count,int *file_ptr,char *present_path,int *tree_ptr,msn_session *session,int *cm_recvsock,int *cm_sendsock,pthread_t *file,print_buf *print);
void make_dir(char *tmp_present_path,char *tmp_dir_name);
void remove_dir(list_file *head,char *present_path,char *tmp_remove);
void connect_recv_msnftp(int data_sock,char *data_send_buf,char *data_recv_buf);
void connect_send_msnftp(int data_sock,char *data_send_buf,char *data_recv_buf);


/* db_con */
void connect_db(MYSQL *conn);
int user_check(MYSQL *conn,char *username);
void db_user_add(MYSQL *conn,char *username);
void db_update_last_time(MYSQL *conn,char *username);
void db_insert_file(MYSQL *conn,char *username);
void db_insert_dir(MYSQL *conn,char *username,char *dirname,char *present_path);
void db_delete_dir_file(MYSQL *conn,char *username,char *filename,char *present_path);

==> openmsghard-1.0.0.tar.gz: openmsghard-1.0.0/common.h <==
#include <dirent.h>
#include <sys/stat.h>
#include <pthread.h>
#include <mysql.h>
#include <iconv.h>

#define MAX_BUF 1024

int pub_ns_sock;
pthread_mutex_t mutx;
int pthread_state;
iconv_t msn_ic[2];







typedef struct _msn_session {
        int trid;


} msn_session;

typedef struct _data {
	char username[256];
        int count; /* 1 ŭ */
	int list_num; /* 1 10 ȣο  , ׿ܴ 0 */
        int isdir; 
        char filename[256];
        char initial[44];
        float size;
        char unit[2];
        long ori_date;
        char date[9];
	long ori_size;
}list_data;


typedef struct _file {
        list_data data;
        struct _file *Next;

}list_file;

typedef struct _print_buf {


        const char *header;
        const char *s_tailer;
        const char *f_tailer;
        const char *m_tailer;
        const char *l_tailer;
        const char *l_s_tailer;
        const char *l_f_tailer;
        const char *l_m_tailer;
        const char *l_l_tailer;
        const char *help_header;
        const char *help_tailer;
        char *u_header;
        char *u_s_tailer;
        char *u_f_tailer;
        char *u_m_tailer;
        char *u_l_tailer;
        char *u_l_s_tailer;
        char *u_l_f_tailer;
        char *u_l_m_tailer;
        char *u_l_l_tailer;


        char *u_help_header;
        char *u_help_tailer;



/*
        char header[MAX_BUF];
        char s_tailer[MAX_BUF];
        char f_tailer[MAX_BUF];
        char m_tailer[MAX_BUF];
        char l_tailer[MAX_BUF];
        char help_header[MAX_BUF];
        char help_tailer[MAX_BUF];

        char u_header[MAX_BUF];
        char u_s_tailer[MAX_BUF];
        char u_f_tailer[MAX_BUF];
        char u_m_tailer[MAX_BUF];
        char u_l_tailer[MAX_BUF];
        char u_help_header[MAX_BUF];
        char u_help_tailer[MAX_BUF];
*/

} print_buf;

print_buf *pub_print;
//set_printbuf(&print);

typedef struct _host_info {
	int *sendsock;
	int *recvsock;	
	char ip[16];
	int port;
	long cookie;
	long authcookie;
	char filename[256];
	long filesize;
	char path[2048];
	char type[5];
	int tree_ptr;
	list_file *head;
}host_info;

struct _file_queue {
	int *sendsock;
	int *recvsock;
        char ip[16];
        int port;
        long cookie;
        long authcookie;
        char filename[256];
        long filesize;
        char path[2048];
        char type[5];
	int tree_ptr;
	list_file *head;
	
} file_queue[11];

typedef struct _config {
	char msn_id[256];
	char msn_pw[256];
	char ip[30];
	int port;
	char mysql_id[256];
	char mysql_pw[256];
	char mysql_db[256];
	char intro_message[1024];
	char nick_name[256];
	char msghard_home[2048];
	char user[256];
	char group[256];
	long default_size;
} config;

/* public  */
int queue_ptr;
int dn_ptr;
int dn_flag;
list_file *pub_head;
int pub_max_count;
int pub_file_ptr;
int pub_tree_ptr;
int pub_data_sock;
char pub_present_path[2048];
char user_id[256];
int pub_mode;

//int pub_get_list_max_count;


msn_session *pub_session;
config conf;

MYSQL conn;



/* list_file.c */
list_file* get_list_file(char *dirname,int *max_count);
void dostat(char *dirname, char *filename ,list_file *head,list_file *tail);
void show_file_info( char *, struct stat *,list_file *head,list_file *tail,char *filename);
void delete_all(list_file *head,int max_count);
void cd_p(char *old_path,char *new_path);
void cd_mv(char *old_path,char *new_path,char dir);
void mv_present(char *present_path);


/* main.c */
void conv_server(msn_session *session,int *cm_sendsock,int *cm_recvsock,char *user_id,print_buf *print);
void z_handler(int sig);
void set_send_message(msn_session *session,list_file *head,char *u_send_buf,char *u_send_buf1,char *u_send_ptr1,int max_count,int file_ptr ,char *present_path,print_buf *print,char *tmp_format); 
void msn_remove_user(msn_session *session,int *sock,char *username);
void msn_user_add(msn_session *session,int *sock,char *username);
void create_home(char *username);
void *ping_pthread(void *sock);
void *typinguser_pthread(void *sock);
void daemonize();
void change_nickname(msn_session *session,int *sock);

/* connect.c */
int msn_init_session(msn_session *session);
char* getaddr(char *domain);
char* msn_ds_connect(msn_session *session,char *ip_port[]);
int tcp_connect(char *server,int port);
int tcp_bind(char *server,int port,int *serv_sock);
int tcp_recv_accept(int *serv_sock);
int tcp_send_accept(int *serv_sock);

void msn_strtok(char *buf,char *tok[]);
void msn_strtok_null(char *buf,char *tok[]);
void ip_port_tok(char *buf,char *ip_port[]);
void remove_r_n(char *buf);
void msn_strtok_path(char *buf,char *tok[]);
void msn_strtok_n(char *buf,char *tok[]);
void msn_strtok_ft(char *buf,char *new_buf);
void msn_strtok_msg(char *buf,char *tok[]);
void msn_strtok_rm(char *buf,char *tok[]);
void blank_two_tok(char *buf,char *tok[]);
/* misc.c */
int check_for_updates(void);
int url_encode(char *str, char *ret, int ret_len);
int url_decode(char *);
int err_exit(char *);
void print_fail(void);
void print_ok(void);
void status(char *);
char *split(char *, char, int);
void usage(void);
void error_handling(char *str);
char* utf8_to_euckr( const char* str );
char* euckr_to_utf8( const char* str );
void utf8encode(iconv_t ic, char *src, char *dest, int obl);
void set_printbuf(print_buf *print);



/* ssl.c */
int https_auth(char *,int,char *,char *,char *,char *,char *,int);

/* filetrans.c */
void file_trans(list_file *head,char *msg_tok[],char *type,int *cm_recvsock,int *cm_sendsock,msn_session *session,pthread_t *file,char *tmp_present_path,int sendnum,int tree_ptr);
void *file_trans_pthread(void *info);
void add_queue(host_info *info);
void del_queue(long cookie);
void file_rename(char *old_name, char *new_name,char *recv_name,char **rename_tok);
void order_queue(int num,long cookie);

/* recvfile.c */
void start_recv(int *data_sock);
void recv_success(int *data_sock);
void recv_failed(int *data_sock);
void ready_recv();


/* sendfile.c */
void start_send(int *data_sock);
void ready_send();


/* msg_proc */
void message_process(list_file *head,char *recv_msg,int *max_count,int *file_ptr,char *present_path,int *tree_ptr,msn_session *session,int *cm_recvsock,int *cm_sendsock,pthread_t *file,print_buf *print);
void make_dir(char *tmp_present_path,char *tmp_dir_name);
void remove_dir(list_file *head,char *present_path,char *tmp_remove);
void connect_recv_msnftp(int data_sock,char *data_send_buf,char *data_recv_buf);
void connect_send_msnftp(int data_sock,char *data_send_buf,char *data_recv_buf);
void set_help_page(msn_session *session,char *u_send_buf1,char *u_send_buf2,print_buf *print);
void set_conf_page(msn_session *session,char *u_send_buf1,char *u_send_buf2,print_buf *print);
void set_publist_page(msn_session *session,char *u_send_buf1,char *u_send_buf2,print_buf *print,list_file *publist_head,int *publist_max_count,int *publist_ptr);
void reset_publist_page(msn_session *session,char *u_send_buf1,char *u_send_buf2,print_buf *print,list_file *publist_head,int publist_max_count,int publist_ptr);


/* db_con */
void connect_db(MYSQL *conn);
int user_check(MYSQL *conn,char *username);
void db_user_add(MYSQL *conn,char *username);
void db_update_last_time(MYSQL *conn,char *username);
void db_insert_file(MYSQL *conn,char *username);
void db_insert_dir(MYSQL *conn,char *username,char *dirname,char *present_path);
void db_delete_dir_file(MYSQL *conn,char *username,char *filename,char *present_path);
void db_select_conf(MYSQL *conn,char *username,char *reg_date,int *is_pub,int *order,char *pub_name,long *send_size,long *recv_size,int *send_count,int *recv_count,long *total_size,long *use_size,long *odd_size);
void db_update_pub_name(MYSQL *conn,char *username,char *pub_name);
void db_select_get_publist(MYSQL *conn,char *username,list_file *publist_head,int *publist_max_count);
void db_update_conf_pub_0(MYSQL *conn,char *username);
void db_update_conf_pub_1(MYSQL *conn,char *username);
